package org.apache.bcel.generic;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.util.ByteSequence;

public class BIPUSH extends Instruction implements ConstantPushInstruction {
   private byte b;

   BIPUSH() {
   }

   public BIPUSH(byte b) {
      super((short)16, (short)2);
      this.b = b;
   }

   public void accept(Visitor v) {
      v.visitPushInstruction(this);
      v.visitStackProducer(this);
      v.visitTypedInstruction(this);
      v.visitConstantPushInstruction(this);
      v.visitBIPUSH(this);
   }

   public void dump(DataOutputStream out) throws IOException {
      super.dump(out);
      out.writeByte(this.b);
   }

   public Type getType(ConstantPoolGen cp) {
      return Type.BYTE;
   }

   public Number getValue() {
      return Integer.valueOf(this.b);
   }

   protected void initFromFile(ByteSequence bytes, boolean wide) throws IOException {
      super.setLength(2);
      this.b = bytes.readByte();
   }

   public String toString(boolean verbose) {
      return super.toString(verbose) + " " + this.b;
   }
}
